/*	September 2023, by Ruud Harmsen

	Input as two command line arguments, corresponding
	to the two hex numbers after a MIDI En bend
	event.
	The program recalculates that to a bend up or
	down in cents, assuming the full range of the
	En-event is + or - 2 half tones.
 */

#include <stdlib.h>
#include <stdio.h>
#include <math.h>

int main (int argc, char **argv)
{
   long lsb, msb;
   double bend;

   if (argc != 3)
   {
      fprintf(stderr, "Wrong usage, see comment in source\n");
      exit(1);
   }
   lsb = strtol(argv[1], NULL, 16);
   msb = strtol(argv[2], NULL, 16);

   bend = (msb << 7) + lsb;
   bend -= 0x2000;
   bend = bend / 0x2000 * 200;

   fprintf(stdout, "msb = %s, lsb = %s, bend is %8.3f cents %s (compl. %8.3f)\n",
      argv[2], argv[1], fabs(bend), bend > 0 ? "up" : "dn",
      100 - fabs(bend));

   return 0;
}
